# Q-CTRL Python

The Q-CTRL Python Package provides an intuitive and convenient Python interface
to Q-CTRL's quantum control solutions for customers of Q-CTRL. To use the Q-CTRL
Python Package, you will need a
[Boulder Opal](https://q-ctrl.com/products/boulder-opal/) account.
